"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const spec_1 = require("@specron/spec");
const web3_sandbox_1 = require("@0xcert/web3-sandbox");
const context_1 = require("../../../core/context");
const spec = new spec_1.Spec();
spec.before((stage) => __awaiter(this, void 0, void 0, function* () {
    const protocol = new web3_sandbox_1.Protocol(stage.web3);
    stage.set('protocol', yield protocol.deploy());
}));
spec.before((stage) => __awaiter(this, void 0, void 0, function* () {
    const context = new context_1.Context(stage);
    yield context.attach();
    stage.set('context', context);
}));
spec.before((stage) => __awaiter(this, void 0, void 0, function* () {
    const accounts = yield stage.web3.eth.getAccounts();
    stage.set('coinbase', accounts[0]);
    stage.set('bob', accounts[1]);
}));
spec.test('submits transaction to the network', (ctx) => __awaiter(this, void 0, void 0, function* () {
    const context = ctx.get('context');
    const coinbase = ctx.get('coinbase');
    const bob = ctx.get('bob');
    const xcert = ctx.get('protocol').xcert;
    const resolver = () => __awaiter(this, void 0, void 0, function* () { return xcert.instance.methods.mint(bob, '100', '0x0'); });
    const mutation = yield context.mutate(resolver, coinbase);
    ctx.true(!!mutation.id);
}));
spec.test('handles an error', (ctx) => __awaiter(this, void 0, void 0, function* () {
    const context = ctx.get('context');
    const resolver = () => __awaiter(this, void 0, void 0, function* () { throw 'foo'; });
    try {
        yield context.mutate(resolver);
        ctx.fail();
    }
    catch (error) {
        ctx.is(error.name, 'ConnectorError');
    }
}));
exports.default = spec;
//# sourceMappingURL=mutate-instance-method.test.js.map